@@ -105,6 +105,8 @@ test_that("response variable is a factor (two var problems)", {
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
   expect_error(calculate(gen_iris4, stat = "diff in props"))
+  expect_error(calculate(gen_iris4, stat = "ratio of props"))
+  expect_error(calculate(gen_iris4, stat = "odds ratio"))
 
   expect_error(calculate(gen_iris4, stat = "t"))
 
@@ -122,10 +124,16 @@ test_that("response variable is a factor (two var problems)", {
   expect_silent(
     calculate(gen_iris4a, stat = "diff in props", order = c("large", "small"))
   )
+  expect_silent(
+    calculate(gen_iris4a, stat = "ratio of props", order = c("large", "small"))
+  )
+  expect_silent(
+    calculate(gen_iris4a, stat = "odds ratio", order = c("large", "small"))
+  )
   expect_silent(
     calculate(gen_iris4a, stat = "z", order = c("large", "small"))
   )
-  expect_error(calculate(gen_iris4a, stat = "z"))
+  expect_warning(calculate(gen_iris4a, stat = "z"))
 })
 
 gen_iris5 <- iris %>%
@@ -144,11 +152,11 @@ test_that("two sample mean-type problems are working", {
     specify(Sepal.Width ~ Sepal.Length.Group) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 10, type = "permute")
-  expect_error(calculate(gen_iris5a, stat = "diff in means"))
+  expect_warning(calculate(gen_iris5a, stat = "diff in means"))
   expect_silent(
     calculate(gen_iris5a, stat = "diff in means", order = c(">5", "<=5"))
   )
-  expect_error(calculate(gen_iris5a, stat = "t"))
+  expect_warning(calculate(gen_iris5a, stat = "t"))
   expect_silent(calculate(gen_iris5a, stat = "t", order = c(">5", "<=5")))
 })
 
@@ -216,7 +224,7 @@ test_that("chi-square matches chisq.test value", {
       stats::chisq.test(table(.$Species))
     )) %>%
     dplyr::select(replicate, stat = statistic)
-  expect_equal(infer_way, trad_way)
+  expect_equivalent(infer_way, trad_way)
 
   gen_iris9a <- iris %>%
     specify(Species ~ NULL) %>%
@@ -233,7 +241,7 @@ test_that("chi-square matches chisq.test value", {
       stats::chisq.test(table(.$Species), p = c(0.8, 0.1, 0.1))
     )) %>%
     dplyr::select(replicate, stat = statistic)
-  expect_equal(infer_way, trad_way)
+  expect_equivalent(infer_way, trad_way)
 })
 
 test_that("`order` is working", {
@@ -270,7 +278,8 @@ test_that("`order` is working", {
     calculate(gen_iris11, stat = "diff in means", order = c(">5", "<=4", ">4"))
   )
   # order not given
-  expect_error(calculate(gen_iris11, stat = "diff in means"))
+  expect_warning(calculate(gen_iris11, stat = "diff in means"),
+                 "The statistic is based on a difference or ratio")
 })
 
 gen_iris12 <- iris %>%
@@ -361,6 +370,17 @@ test_that("One sample t hypothesis test is working", {
       generate(reps = 10) %>%
       calculate(stat = "t")
   )
+  
+  expect_message(
+    iris_tbl %>%
+      specify(response = Petal.Width) %>%
+      calculate(stat = "t"),
+    "the t-test will assume a null hypothesis"
+  )
+  
+  iris_tbl %>%
+    specify(response = Petal.Width) %>%
+    calculate(stat = "t", mu = 1)
 })
 
 test_that("specify done before calculate", {
@@ -470,8 +490,42 @@ test_that("calc_impl.count works", {
     sum(iris_tbl$Sepal.Length.Group == ">5")
   )
 
-  expect_equal(
+  expect_equivalent(
     gen_iris12 %>% calculate(stat = "count"),
     gen_iris12 %>% dplyr::summarise(stat = sum(Sepal.Length.Group == ">5"))
   )
 })
+
+
+gss_biased <- gss %>% 
+  dplyr::filter(!(sex == "male" & college == "no degree" & age < 40))
+
+gss_tbl <- table(gss_biased$sex, gss_biased$college)
+
+test_that("calc_impl.odds_ratio works", {
+  base_odds_ratio <- {(gss_tbl[1,1] * gss_tbl[2,2]) / 
+    (gss_tbl[1,2] * gss_tbl[2,1])}
+  
+  expect_equal(
+    gss_biased %>% 
+      specify(college ~ sex, success = "degree") %>%
+      calculate(stat = "odds ratio", order = c("female", "male")) %>%
+      dplyr::pull(),
+    expected = base_odds_ratio,
+    tolerance = .001)
+})
+
+test_that("calc_impl.ratio_of_props works", {
+  base_ratio_of_props <- {(gss_tbl[1,2] / sum(gss_tbl[1,])) / 
+      (gss_tbl[2,2] / sum(gss_tbl[2,]))}
+  
+  expect_equal(
+    gss_biased %>% 
+      specify(college ~ sex, success = "degree") %>%
+      calculate(stat = "ratio of props", order = c("male", "female")) %>%
+      dplyr::pull(),
+    expected = base_ratio_of_props,
+    tolerance = .001)
+  
+})
+
