@@ -61,9 +61,18 @@ test_that("shade_p_value accepts synonyms for 'direction'", {
   expect_doppelganger(
     "pval-direction-left", iris_viz_sim + shade_p_value(1, "less")
   )
+  # This currently results into the following {vdiffr} warning:
+  # "Duplicated expectations: pval-direction-both, pval-direction-both"
+  # However, having same figure here as expectation is exactly the goal of tests
   expect_doppelganger(
     "pval-direction-both", iris_viz_sim + shade_p_value(1, "two_sided")
   )
+  expect_doppelganger(
+    "pval-direction-both", iris_viz_sim + shade_p_value(1, "two-sided")
+  )
+  expect_doppelganger(
+    "pval-direction-both", iris_viz_sim + shade_p_value(1, "two sided")
+  )
 })
 
 test_that("shade_p_value uses extra aesthetic", {
@@ -92,6 +101,21 @@ test_that("shade_p_value throws errors", {
   expect_error(iris_viz_sim + shade_p_value(1, 1), "character")
   expect_error(iris_viz_sim + shade_p_value(1, "right", color = "x"), "color")
   expect_error(iris_viz_sim + shade_p_value(1, "right", fill = "x"), "color")
+  expect_error(iris_viz_sim %>% shade_p_value(1, "right"), 
+               "\\`shade_p_value\\(\\)\\` as a layer")
+  expect_error(iris_viz_sim %>% shade_p_value(obs_stat = 1), 
+               "\\`shade_p_value\\(\\)\\` as a layer")
+  expect_error(iris_viz_sim %>% shade_p_value(obs_stat = 1, 
+                                              direction = "right"), 
+               "\\`shade_p_value\\(\\)\\` as a layer")
+  expect_error(iris_viz_sim %>% shade_pvalue(1, "right"), 
+               "\\`shade_pvalue\\(\\)\\` as a layer")
+  expect_error(iris_viz_sim %>% shade_pvalue(obs_stat = 1), 
+               "\\`shade_pvalue\\(\\)\\` as a layer")
+  expect_error(iris_viz_sim %>% shade_pvalue(obs_stat = 1, 
+                                              direction = "right"), 
+               "\\`shade_pvalue\\(\\)\\` as a layer")
+  
 })
 
 
@@ -102,5 +126,7 @@ test_that("norm_direction works", {
   expect_equal(norm_direction("right"), "right")
   expect_equal(norm_direction("greater"), "right")
   expect_equal(norm_direction("both"), "both")
+  expect_equal(norm_direction("two-sided"), "both")
   expect_equal(norm_direction("two_sided"), "both")
+  expect_equal(norm_direction("two sided"), "both")
 })
