@@ -46,3 +46,11 @@ test_that("get_type works", {
   expect_equal(get_type(list(x = 1)), "list")
   expect_equal(get_type(TRUE), "logical")
 })
+
+test_that("c_dedupl returns input when unnamed", {
+  expect_equal(c_dedupl(c(1, 2, 3)), c(1, 2, 3))
+})
+
+test_that("hypothesize errors out when x isn't a dataframe",
+          expect_error(hypothesize(c(1, 2, 3), null = "point"), 
+                       "x must be a data.frame or tibble"))
